@@ -202,6 +202,14 @@ class ReadingTest(unittest.TestCase):
         self.failUnlessEqual(f['id'], "0")
         self.failUnlessEqual(f['properties']['FIPS_CNTRY'], 'UK')
 
+    def test_no_write(self):
+        self.assertRaises(IOError, self.c.write, {})
+
+class FilterReadingTest(unittest.TestCase):
+    def setUp(self):
+        self.c = fiona.open("docs/data/test_uk.shp", "r")
+    def tearDown(self):
+        self.c.close()
     def test_filter_1(self):
         results = list(self.c.filter(bbox=(-15.0, 35.0, 15.0, 65.0)))
         self.failUnlessEqual(len(results), 48)
@@ -209,9 +217,6 @@ class ReadingTest(unittest.TestCase):
         self.failUnlessEqual(f['id'], "0")
         self.failUnlessEqual(f['properties']['FIPS_CNTRY'], 'UK')
 
-    def test_no_write(self):
-        self.assertRaises(IOError, self.c.write, {})
-
 class UnsupportedDriverTest(unittest.TestCase):
     
     def test_immediate_fail_driver(self):
@@ -481,6 +486,6 @@ class GeoJSONCRSWritingTest(unittest.TestCase):
         info = subprocess.check_output(
             ["ogrinfo", self.filename, "OGRGeoJSON"])
         self.assert_(
-            'GEOGCS["WGS 84' in info,
+            'GEOGCS["WGS 84' in info.decode('utf-8'),
             info)
 
